# je_api_testka

---

### API Testka as a tool for API Test

#### Features
* HTTP Method test 
* Get response data body etc...
* Action file and executor
* result compare
* xml to json and json to xml
* Soap test
* CLI with action file

---

[![CircleCI](https://circleci.com/gh/JE-Chen/APITestka/tree/main.svg?style=svg&circle-token=32826b3cccdffba93891691795bbded287a0b7fe)](https://circleci.com/gh/JE-Chen/APITestka/tree/main)

### Documentation

[![Documentation Status](https://readthedocs.org/projects/apitestka/badge/?version=latest)](https://apitestka.readthedocs.io/en/latest/?badge=latest)

https://apitestka.readthedocs.io/en/latest/

---

## install 

```
pip install je_api_testka
```